summaryrefslogtreecommitdiff
path: root/tools/ci/scripts/runtest.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tools/ci/scripts/runtest.sh')
-rwxr-xr-xtools/ci/scripts/runtest.sh16
1 files changed, 8 insertions, 8 deletions
diff --git a/tools/ci/scripts/runtest.sh b/tools/ci/scripts/runtest.sh
index 7c41da5ce..bb31d5067 100755
--- a/tools/ci/scripts/runtest.sh
+++ b/tools/ci/scripts/runtest.sh
@@ -52,7 +52,7 @@ function wait_for_servers_list {
function run {
./src/manaplus --hide-cursor --enable-ipc --renderer=0 >logs/run.log 2>&1 &
export PID=$!
- echo "manaplus PID: ${PID}"
+ echo "manaverse PID: ${PID}"
sleep 20
echo "pause after run"
wait_for_servers_list
@@ -98,16 +98,16 @@ function send_command {
}
function check_exists {
- if [ ! -f "logs/home/Desktop/ManaPlus/$1" ]; then
+ if [ ! -f "logs/home/Desktop/ManaVerse/$1" ]; then
sleep 10
- if [ ! -f "logs/home/Desktop/ManaPlus/$1" ]; then
+ if [ ! -f "logs/home/Desktop/ManaVerse/$1" ]; then
echo "Error: image $1 not exists"
exit 1
fi
fi
- if [ ! -f "logs/home/Desktop/ManaPlus/$2" ]; then
+ if [ ! -f "logs/home/Desktop/ManaVerse/$2" ]; then
sleep 10
- if [ ! -f "logs/home/Desktop/ManaPlus/$2" ]; then
+ if [ ! -f "logs/home/Desktop/ManaVerse/$2" ]; then
echo "Error: image $2 not exists"
exit 1
fi
@@ -116,7 +116,7 @@ function check_exists {
function imagesdiff {
check_exists "$1" "$2"
- diff "logs/home/Desktop/ManaPlus/$1" "logs/home/Desktop/ManaPlus/$2"
+ diff "logs/home/Desktop/ManaVerse/$1" "logs/home/Desktop/ManaVerse/$2"
if [ "$?" == 0 ]; then
echo "Error: images '$1' and '$2' is same."
exit 1
@@ -125,7 +125,7 @@ function imagesdiff {
function imagessame {
check_exists "$1" "$2"
- diff "logs/home/Desktop/ManaPlus/$1" "logs/home/Desktop/ManaPlus/$2"
+ diff "logs/home/Desktop/ManaVerse/$1" "logs/home/Desktop/ManaVerse/$2"
if [ "$?" != 0 ]; then
echo "Error: images '$1' and '$2' is different."
exit 1
@@ -236,7 +236,7 @@ imagesdiff new_server.png about.png
send_command "/sendmousekey 500 20 1"
send_command "/screenshot about.png"
# open about manaplus page
send_command "/sendmousekey 300 ${ABOUTYOFFSET} 1"
send_command "/screenshot about2.png"
imagesdiff about.png about2.png
@@ -236,7 +236,7 @@ imagesdiff new_server.png about.png
send_command "/sendmousekey 500 20 1"
send_command "/screenshot about.png"
-# open about manaplus page
+# open about manaverse page
send_command "/sendmousekey 300 ${ABOUTYOFFSET} 1"
send_command "/screenshot about2.png"